==> tuia-advert-center-api-1.5.9-20180715.071954-11-sources.jar: cn/com/duiba/tuia/core/api/dto/finance/AccountReconciliationDataDto.java <==
package cn.com.duiba.tuia.core.api.dto.finance;

public class AccountReconciliationDataDto {

    public AccountReconciliationDataDto(){
        beginBalance = 0L;
        endBalance = 0L;
        beginCash = 0L;
        beginCashBack = 0L;
        balanceIn = 0L;
        balanceOut= 0L;
        balanceInCash= 0L;
        balanceInCashRecharge= 0L;
        balanceInCashTransfer= 0L;
        balanceInCashBack= 0L;
        balanceInCashBackRecharge= 0L;
        balanceInCashBackTransfer= 0L;
        balanceOutCash= 0L;
        balanceOutCashConsume= 0L;
        balanceOutCashTransfer= 0L;
        balanceOutCashRefund= 0L;
        balanceOutCashPartialRepair= 0L;
        balanceOutCashAdjust= 0L;
        balanceOutCashOther= 0L;
        balanceOutCashBack= 0L;
        balanceOutCashBackConsume= 0L;
        balanceOutCashBackTransfer= 0L;
        balanceOutCashBackRefund= 0L;
        balanceOutCashBackPartialRepair= 0L;
        balanceOutCashBackAdjust= 0L;
        balanceOutCashBackOther= 0L;
        endBalanceCash= 0L;
        endBalanceCashBack= 0L;
        creditLimit= 0L;
    }
    /**
     * 账户名称
     */
    private String accountName;

    /**
     * 账户ID
     */
    private Long accountId;

    /**
     * 账户类型
     */
    private String accountType;

    /**
     * 期初余额
     */
    private Long beginBalance;

    /**
     * 期末余额
     */
    private Long endBalance;

    /**
     * 期初余额 --- 现金
     */
    private Long beginCash;

    /**
     * 期初余额 --- 返货
     */
    private Long beginCashBack;

    /**
     * 存入
     */
    private Long balanceIn;

    /**
     * 支出
     */
    private Long balanceOut;

    /**
     * 存入 --- 现金
     */
    private Long balanceInCash;

    /**
     * 存入 --- 现金 --- 充值
     */
    private Long balanceInCashRecharge;

    /**
     * 存入 --- 现金 --- 划转
     */
    private Long balanceInCashTransfer;
    /**
     * 存入 --- 返货
     */
    private Long balanceInCashBack;

    /**
     * 存入 --- 返货 --- 充值
     */
    private Long balanceInCashBackRecharge;


    /**
     * 存入 --- 返货 --- 划转
     */
    private Long balanceInCashBackTransfer;


    /**
     * 支出 --- 现金
     */
    private Long balanceOutCash;

    /**
     * 支出 --- 现金 --- 消耗
     */
    private Long balanceOutCashConsume;

    /**
     * 支出 --- 现金 --- 划转
     */
    private Long balanceOutCashTransfer;

    /**
     * 支出 --- 现金 --- 退款
     */
    private Long balanceOutCashRefund;

    /**
     * 支出 --- 现金 --- 修偏
     */
    private Long balanceOutCashPartialRepair;

    /**
     * 支出 --- 现金 --- 调整
     */
    private Long balanceOutCashAdjust;

    /**
     * 支出 --- 现金 --- 其他
     */
    private Long balanceOutCashOther;

    /**
     * 支出 --- 返货
     */
    private Long balanceOutCashBack;

    /**
     * 支出 --- 返货 --- 消耗
     */
    private Long balanceOutCashBackConsume;

    /**
     * 支出 --- 返货 --- 划转
     */
    private Long balanceOutCashBackTransfer;

    /**
     * 支出 --- 返货 --- 退款
     */
    private Long balanceOutCashBackRefund;

    /**
     * 支出 --- 返货 --- 修偏
     */
    private Long balanceOutCashBackPartialRepair;

    /**
     * 支出 --- 返货 --- 调整
     */
    private Long balanceOutCashBackAdjust;

    /**
     * 支出 --- 返货 --- 其他
     */
    private Long balanceOutCashBackOther;

    /**
     * 期末余额 --- 现金
     */
    private Long endBalanceCash;

    /**
     * 期末余额 --- 返货
     */
    private Long endBalanceCashBack;

    /**
     * 信用额度
     **/
    private Long creditLimit;

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }


    public Long getBeginBalance() {
        return beginBalance;
    }

    public void setBeginBalance(Long beginBalance) {
        this.beginBalance = beginBalance;
    }

    public Long getEndBalance() {
        return endBalance;
    }

    public void setEndBalance(Long endBalance) {
        this.endBalance = endBalance;
    }

    public Long getBeginCash() {
        return beginCash;
    }

    public void setBeginCash(Long beginCash) {
        this.beginCash = beginCash;
    }

    public Long getBeginCashBack() {
        return beginCashBack;
    }

    public void setBeginCashBack(Long beginCashBack) {
        this.beginCashBack = beginCashBack;
    }

    public Long getBalanceIn() {
        return balanceIn;
    }

    public void setBalanceIn(Long balanceIn) {
        this.balanceIn = balanceIn;
    }

    public Long getBalanceOut() {
        return balanceOut;
    }

    public void setBalanceOut(Long balanceOut) {
        this.balanceOut = balanceOut;
    }

    public Long getBalanceInCash() {
        return balanceInCash;
    }

    public void setBalanceInCash(Long balanceInCash) {
        this.balanceInCash = balanceInCash;
    }

    public Long getBalanceInCashRecharge() {
        return balanceInCashRecharge;
    }

    public void setBalanceInCashRecharge(Long balanceInCashRecharge) {
        this.balanceInCashRecharge = balanceInCashRecharge;
    }

    public Long getBalanceInCashTransfer() {
        return balanceInCashTransfer;
    }

    public void setBalanceInCashTransfer(Long balanceInCashTransfer) {
        this.balanceInCashTransfer = balanceInCashTransfer;
    }

    public Long getBalanceInCashBackRecharge() {
        return balanceInCashBackRecharge;
    }

    public void setBalanceInCashBackRecharge(Long balanceInCashBackRecharge) {
        this.balanceInCashBackRecharge = balanceInCashBackRecharge;
    }

    public Long getBalanceInCashBackTransfer() {
        return balanceInCashBackTransfer;
    }

    public void setBalanceInCashBackTransfer(Long balanceInCashBackTransfer) {
        this.balanceInCashBackTransfer = balanceInCashBackTransfer;
    }

    public Long getBalanceOutCash() {
        return balanceOutCash;
    }

    public void setBalanceOutCash(Long balanceOutCash) {
        this.balanceOutCash = balanceOutCash;
    }

    public Long getBalanceOutCashConsume() {
        return balanceOutCashConsume;
    }

    public void setBalanceOutCashConsume(Long balanceOutCashConsume) {
        this.balanceOutCashConsume = balanceOutCashConsume;
    }

    public Long getBalanceOutCashTransfer() {
        return balanceOutCashTransfer;
    }

    public void setBalanceOutCashTransfer(Long balanceOutCashTransfer) {
        this.balanceOutCashTransfer = balanceOutCashTransfer;
    }

    public Long getBalanceOutCashRefund() {
        return balanceOutCashRefund;
    }

    public void setBalanceOutCashRefund(Long balanceOutCashRefund) {
        this.balanceOutCashRefund = balanceOutCashRefund;
    }

    public Long getBalanceOutCashPartialRepair() {
        return balanceOutCashPartialRepair;
    }

    public void setBalanceOutCashPartialRepair(Long balanceOutCashPartialRepair) {
        this.balanceOutCashPartialRepair = balanceOutCashPartialRepair;
    }

    public Long getBalanceOutCashOther() {
        return balanceOutCashOther;
    }

    public void setBalanceOutCashOther(Long balanceOutCashOther) {
        this.balanceOutCashOther = balanceOutCashOther;
    }

    public Long getBalanceOutCashBack() {
        return balanceOutCashBack;
    }

    public void setBalanceOutCashBack(Long balanceOutCashBack) {
        this.balanceOutCashBack = balanceOutCashBack;
    }

    public Long getBalanceOutCashBackConsume() {
        return balanceOutCashBackConsume;
    }

    public void setBalanceOutCashBackConsume(Long balanceOutCashBackConsume) {
        this.balanceOutCashBackConsume = balanceOutCashBackConsume;
    }

    public Long getBalanceOutCashBackTransfer() {
        return balanceOutCashBackTransfer;
    }

    public void setBalanceOutCashBackTransfer(Long balanceOutCashBackTransfer) {
        this.balanceOutCashBackTransfer = balanceOutCashBackTransfer;
    }

    public Long getBalanceOutCashBackRefund() {
        return balanceOutCashBackRefund;
    }

    public void setBalanceOutCashBackRefund(Long balanceOutCashBackRefund) {
        this.balanceOutCashBackRefund = balanceOutCashBackRefund;
    }

    public Long getBalanceOutCashBackPartialRepair() {
        return balanceOutCashBackPartialRepair;
    }

    public void setBalanceOutCashBackPartialRepair(Long balanceOutCashBackPartialRepair) {
        this.balanceOutCashBackPartialRepair = balanceOutCashBackPartialRepair;
    }

    public Long getBalanceOutCashBackOther() {
        return balanceOutCashBackOther;
    }

    public void setBalanceOutCashBackOther(Long balanceOutCashBackOther) {
        this.balanceOutCashBackOther = balanceOutCashBackOther;
    }

    public Long getEndBalanceCash() {
        return endBalanceCash;
    }

    public void setEndBalanceCash(Long endBalanceCash) {
        this.endBalanceCash = endBalanceCash;
    }

    public Long getEndBalanceCashBack() {
        return endBalanceCashBack;
    }

    public void setEndBalanceCashBack(Long endBalanceCashBack) {
        this.endBalanceCashBack = endBalanceCashBack;
    }

    public Long getCreditLimit() {
        return creditLimit;
    }

    public void setCreditLimit(Long creditLimit) {
        this.creditLimit = creditLimit;
    }

    public Long getBalanceInCashBack() {
        return balanceInCashBack;
    }

    public void setBalanceInCashBack(Long balanceInCashBack) {
        this.balanceInCashBack = balanceInCashBack;
    }

    public Long getBalanceOutCashAdjust() {
        return balanceOutCashAdjust;
    }

    public void setBalanceOutCashAdjust(Long balanceOutCashAdjust) {
        this.balanceOutCashAdjust = balanceOutCashAdjust;
    }

    public Long getBalanceOutCashBackAdjust() {
        return balanceOutCashBackAdjust;
    }

    public void setBalanceOutCashBackAdjust(Long balanceOutCashBackAdjust) {
        this.balanceOutCashBackAdjust = balanceOutCashBackAdjust;
    }

    public String getAccountType() {
        return accountType;
    }

    public void setAccountType(String accountType) {
        this.accountType = accountType;
    }
}

==> tuia-advert-center-api-2.5.50-sources.jar: cn/com/duiba/tuia/core/api/dto/finance/AccountReconciliationDataDto.java <==
package cn.com.duiba.tuia.core.api.dto.finance;

import java.io.Serializable;

public class AccountReconciliationDataDto  implements Serializable {

    private static final long serialVersionUID = 2262737432354870258L;

    public AccountReconciliationDataDto(){
        beginBalance = 0L;
        endBalance = 0L;
        beginCash = 0L;
        beginCashBack = 0L;
        balanceIn = 0L;
        balanceOut= 0L;
        balanceInCash= 0L;
        balanceInCashRecharge= 0L;
        balanceInCashTransfer= 0L;
        balanceInCashBack= 0L;
        balanceInCashBackRecharge= 0L;
        balanceInCashBackTransfer= 0L;
        balanceOutCash= 0L;
        balanceOutCashConsume= 0L;
        balanceOutCashTransfer= 0L;
        balanceOutCashRefund= 0L;
        balanceOutCashPartialRepair= 0L;
        balanceOutCashAdjust= 0L;
        balanceOutCashOther= 0L;
        balanceOutCashBack= 0L;
        balanceOutCashBackConsume= 0L;
        balanceOutCashBackTransfer= 0L;
        balanceOutCashBackRefund= 0L;
        balanceOutCashBackPartialRepair= 0L;
        balanceOutCashBackAdjust= 0L;
        balanceOutCashBackOther= 0L;
        endBalanceCash= 0L;
        endBalanceCashBack= 0L;
        creditLimit= 0L;
    }
    /**
     * 账户名称
     */
    private String accountName;

    /**
     * 账户ID
     */
    private Long accountId;

    /**
     * 账户类型
     */
    private String accountType;

    /**
     * 期初余额
     */
    private Long beginBalance;

    /**
     * 期末余额
     */
    private Long endBalance;

    /**
     * 期初余额 --- 现金
     */
    private Long beginCash;

    /**
     * 期初余额 --- 返货
     */
    private Long beginCashBack;

    /**
     * 存入
     */
    private Long balanceIn;

    /**
     * 支出
     */
    private Long balanceOut;

    /**
     * 存入 --- 现金
     */
    private Long balanceInCash;

    /**
     * 存入 --- 现金 --- 充值
     */
    private Long balanceInCashRecharge;

    /**
     * 存入 --- 现金 --- 划转
     */
    private Long balanceInCashTransfer;
    /**
     * 存入 --- 返货
     */
    private Long balanceInCashBack;

    /**
     * 存入 --- 返货 --- 充值
     */
    private Long balanceInCashBackRecharge;


    /**
     * 存入 --- 返货 --- 划转
     */
    private Long balanceInCashBackTransfer;


    /**
     * 支出 --- 现金
     */
    private Long balanceOutCash;

    /**
     * 支出 --- 现金 --- 消耗
     */
    private Long balanceOutCashConsume;

    /**
     * 支出 --- 现金 --- 划转
     */
    private Long balanceOutCashTransfer;

    /**
     * 支出 --- 现金 --- 退款
     */
    private Long balanceOutCashRefund;

    /**
     * 支出 --- 现金 --- 修偏
     */
    private Long balanceOutCashPartialRepair;

    /**
     * 支出 --- 现金 --- 调整
     */
    private Long balanceOutCashAdjust;

    /**
     * 支出 --- 现金 --- 其他
     */
    private Long balanceOutCashOther;

    /**
     * 支出 --- 返货
     */
    private Long balanceOutCashBack;

    /**
     * 支出 --- 返货 --- 消耗
     */
    private Long balanceOutCashBackConsume;

    /**
     * 支出 --- 返货 --- 划转
     */
    private Long balanceOutCashBackTransfer;

    /**
     * 支出 --- 返货 --- 退款
     */
    private Long balanceOutCashBackRefund;

    /**
     * 支出 --- 返货 --- 修偏
     */
    private Long balanceOutCashBackPartialRepair;

    /**
     * 支出 --- 返货 --- 调整
     */
    private Long balanceOutCashBackAdjust;

    /**
     * 支出 --- 返货 --- 其他
     */
    private Long balanceOutCashBackOther;

    /**
     * 期末余额 --- 现金
     */
    private Long endBalanceCash;

    /**
     * 期末余额 --- 返货
     */
    private Long endBalanceCashBack;

    /**
     * 信用额度
     **/
    private Long creditLimit;

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }


    public Long getBeginBalance() {
        return beginBalance;
    }

    public void setBeginBalance(Long beginBalance) {
        this.beginBalance = beginBalance;
    }

    public Long getEndBalance() {
        return endBalance;
    }

    public void setEndBalance(Long endBalance) {
        this.endBalance = endBalance;
    }

    public Long getBeginCash() {
        return beginCash;
    }

    public void setBeginCash(Long beginCash) {
        this.beginCash = beginCash;
    }

    public Long getBeginCashBack() {
        return beginCashBack;
    }

    public void setBeginCashBack(Long beginCashBack) {
        this.beginCashBack = beginCashBack;
    }

    public Long getBalanceIn() {
        return balanceIn;
    }

    public void setBalanceIn(Long balanceIn) {
        this.balanceIn = balanceIn;
    }

    public Long getBalanceOut() {
        return balanceOut;
    }

    public void setBalanceOut(Long balanceOut) {
        this.balanceOut = balanceOut;
    }

    public Long getBalanceInCash() {
        return balanceInCash;
    }

    public void setBalanceInCash(Long balanceInCash) {
        this.balanceInCash = balanceInCash;
    }

    public Long getBalanceInCashRecharge() {
        return balanceInCashRecharge;
    }

    public void setBalanceInCashRecharge(Long balanceInCashRecharge) {
        this.balanceInCashRecharge = balanceInCashRecharge;
    }

    public Long getBalanceInCashTransfer() {
        return balanceInCashTransfer;
    }

    public void setBalanceInCashTransfer(Long balanceInCashTransfer) {
        this.balanceInCashTransfer = balanceInCashTransfer;
    }

    public Long getBalanceInCashBackRecharge() {
        return balanceInCashBackRecharge;
    }

    public void setBalanceInCashBackRecharge(Long balanceInCashBackRecharge) {
        this.balanceInCashBackRecharge = balanceInCashBackRecharge;
    }

    public Long getBalanceInCashBackTransfer() {
        return balanceInCashBackTransfer;
    }

    public void setBalanceInCashBackTransfer(Long balanceInCashBackTransfer) {
        this.balanceInCashBackTransfer = balanceInCashBackTransfer;
    }

    public Long getBalanceOutCash() {
        return balanceOutCash;
    }

    public void setBalanceOutCash(Long balanceOutCash) {
        this.balanceOutCash = balanceOutCash;
    }

    public Long getBalanceOutCashConsume() {
        return balanceOutCashConsume;
    }

    public void setBalanceOutCashConsume(Long balanceOutCashConsume) {
        this.balanceOutCashConsume = balanceOutCashConsume;
    }

    public Long getBalanceOutCashTransfer() {
        return balanceOutCashTransfer;
    }

    public void setBalanceOutCashTransfer(Long balanceOutCashTransfer) {
        this.balanceOutCashTransfer = balanceOutCashTransfer;
    }

    public Long getBalanceOutCashRefund() {
        return balanceOutCashRefund;
    }

    public void setBalanceOutCashRefund(Long balanceOutCashRefund) {
        this.balanceOutCashRefund = balanceOutCashRefund;
    }

    public Long getBalanceOutCashPartialRepair() {
        return balanceOutCashPartialRepair;
    }

    public void setBalanceOutCashPartialRepair(Long balanceOutCashPartialRepair) {
        this.balanceOutCashPartialRepair = balanceOutCashPartialRepair;
    }

    public Long getBalanceOutCashOther() {
        return balanceOutCashOther;
    }

    public void setBalanceOutCashOther(Long balanceOutCashOther) {
        this.balanceOutCashOther = balanceOutCashOther;
    }

    public Long getBalanceOutCashBack() {
        return balanceOutCashBack;
    }

    public void setBalanceOutCashBack(Long balanceOutCashBack) {
        this.balanceOutCashBack = balanceOutCashBack;
    }

    public Long getBalanceOutCashBackConsume() {
        return balanceOutCashBackConsume;
    }

    public void setBalanceOutCashBackConsume(Long balanceOutCashBackConsume) {
        this.balanceOutCashBackConsume = balanceOutCashBackConsume;
    }

    public Long getBalanceOutCashBackTransfer() {
        return balanceOutCashBackTransfer;
    }

    public void setBalanceOutCashBackTransfer(Long balanceOutCashBackTransfer) {
        this.balanceOutCashBackTransfer = balanceOutCashBackTransfer;
    }

    public Long getBalanceOutCashBackRefund() {
        return balanceOutCashBackRefund;
    }

    public void setBalanceOutCashBackRefund(Long balanceOutCashBackRefund) {
        this.balanceOutCashBackRefund = balanceOutCashBackRefund;
    }

    public Long getBalanceOutCashBackPartialRepair() {
        return balanceOutCashBackPartialRepair;
    }

    public void setBalanceOutCashBackPartialRepair(Long balanceOutCashBackPartialRepair) {
        this.balanceOutCashBackPartialRepair = balanceOutCashBackPartialRepair;
    }

    public Long getBalanceOutCashBackOther() {
        return balanceOutCashBackOther;
    }

    public void setBalanceOutCashBackOther(Long balanceOutCashBackOther) {
        this.balanceOutCashBackOther = balanceOutCashBackOther;
    }

    public Long getEndBalanceCash() {
        return endBalanceCash;
    }

    public void setEndBalanceCash(Long endBalanceCash) {
        this.endBalanceCash = endBalanceCash;
    }

    public Long getEndBalanceCashBack() {
        return endBalanceCashBack;
    }

    public void setEndBalanceCashBack(Long endBalanceCashBack) {
        this.endBalanceCashBack = endBalanceCashBack;
    }

    public Long getCreditLimit() {
        return creditLimit;
    }

    public void setCreditLimit(Long creditLimit) {
        this.creditLimit = creditLimit;
    }

    public Long getBalanceInCashBack() {
        return balanceInCashBack;
    }

    public void setBalanceInCashBack(Long balanceInCashBack) {
        this.balanceInCashBack = balanceInCashBack;
    }

    public Long getBalanceOutCashAdjust() {
        return balanceOutCashAdjust;
    }

    public void setBalanceOutCashAdjust(Long balanceOutCashAdjust) {
        this.balanceOutCashAdjust = balanceOutCashAdjust;
    }

    public Long getBalanceOutCashBackAdjust() {
        return balanceOutCashBackAdjust;
    }

    public void setBalanceOutCashBackAdjust(Long balanceOutCashBackAdjust) {
        this.balanceOutCashBackAdjust = balanceOutCashBackAdjust;
    }

    public String getAccountType() {
        return accountType;
    }

    public void setAccountType(String accountType) {
        this.accountType = accountType;
    }
}
